package com.landray.kmss.sys.attachment.service.spring;

import java.util.Iterator;
import com.landray.kmss.common.dao.HQLInfo;
import com.landray.kmss.sys.attachment.interfaces.ISysAttRtfForm;
import com.landray.kmss.common.actions.RequestContext;
import com.landray.kmss.common.forms.IExtendForm;
import java.util.regex.Matcher;
import java.util.ArrayList;
import java.util.regex.Pattern;
import java.io.InputStream;
import java.util.Date;
import com.landray.kmss.util.FileMimeTypeUtil;
import com.landray.kmss.sys.attachment.model.SysAttRtfData;
import java.io.FileInputStream;
import java.io.File;
import org.hibernate.query.Query;
import java.util.List;
import com.landray.kmss.util.ModelUtil;
import java.util.Collection;
import com.landray.kmss.util.StringUtil;
import com.landray.kmss.sys.attachment.interfaces.ISysAttRtfModel;
import com.landray.kmss.common.model.IBaseModel;
import com.landray.kmss.util.SpringBeanUtil;
import com.landray.kmss.sys.attachment.service.ISysAttMainCoreInnerService;
import com.landray.kmss.sys.filestore.service.ISysAttUploadService;
import com.landray.kmss.sys.attachment.service.ISysAttRtfCoreService;
import com.landray.kmss.common.service.BaseCoreOuterServiceImp;

public class SysAttRtfCoreServiceImp extends BaseCoreOuterServiceImp implements ISysAttRtfCoreService
{
    private static final String imgReg = "<img.*?src=[^>]*?>";
    private static final String srcReg = "\".*?/resource/fckeditor/editor/filemanager/download.*?\"";
    private static final String fdIdReg = "fdId=([^&]*)";
    private static final String videoReg = "<video.*?src=[^>]*?>";
    protected ISysAttUploadService sysAttUploadService;
    protected ISysAttMainCoreInnerService sysAttMainService;
    
    public ISysAttMainCoreInnerService getSysAttMainService() {
        if (this.sysAttMainService == null) {
            this.sysAttMainService = (ISysAttMainCoreInnerService)SpringBeanUtil.getBean("sysAttMainService");
        }
        return this.sysAttMainService;
    }
    
    public ISysAttUploadService getSysAttUploadService() {
        if (this.sysAttUploadService == null) {
            this.sysAttUploadService = (ISysAttUploadService)SpringBeanUtil.getBean("sysAttUploadService");
        }
        return this.sysAttUploadService;
    }
    
    protected void save(final IBaseModel model) throws Exception {
        if (model instanceof ISysAttRtfModel) {
            final ISysAttRtfModel _model = (ISysAttRtfModel)model;
            if (StringUtil.isNull(_model.getDocContent())) {
                return;
            }
            final List<String> fdIds = this.getRtfPics(_model.getDocContent());
            fdIds.addAll(this.getRtfVideos(_model.getDocContent()));
            String sql = "delete com.landray.kmss.sys.attachment.model.SysAttRtfData sysAttRtfData where sysAttRtfData.fdModelName=? and sysAttRtfData.fdModelId=? ";
            if (fdIds.size() > 0) {
                sql = StringUtil.linkString(sql, " and ", "sysAttRtfData.fdId not in(:fdIds)");
            }
            final Query query = this.getSysAttMainService().getBaseDao().getHibernateSession().createQuery(sql);
            query.setString(0, ModelUtil.getModelClassName((Object)_model));
            query.setString(1, model.getFdId());
            if (fdIds.size() > 0) {
                query.setParameterList("fdIds", (Collection)fdIds);
            }
            query.executeUpdate();
        }
    }
    
    public String saveSysAttRtfDataByfilePath(final String fdApplicantId, final String fdModelName, final String filePath) throws Exception {
        final String fileName = filePath.substring(filePath.lastIndexOf(47) + 1);
        final File qrcPIC = new File(filePath);
        final double fdSize = (double)qrcPIC.length();
        final FileInputStream fileInputStream = new FileInputStream(qrcPIC);
        final SysAttRtfData sysAttRtfData = new SysAttRtfData();
        sysAttRtfData.setFdFileName(fileName);
        sysAttRtfData.setFdContentType(FileMimeTypeUtil.getContentType(fileName));
        sysAttRtfData.setDocCreateTime(new Date());
        sysAttRtfData.setInputStream((InputStream)fileInputStream);
        sysAttRtfData.setFdModelId(fdApplicantId);
        sysAttRtfData.setFdModelName(fdModelName);
        sysAttRtfData.setFdSize(Double.valueOf(fdSize));
        final String sysAttRtfDataId = this.getSysAttMainService().addRtfData(sysAttRtfData, (InputStream)fileInputStream);
        if (StringUtil.isNotNull(sysAttRtfDataId)) {
            qrcPIC.delete();
        }
        return sysAttRtfDataId;
    }
    
    private List<String> getRtfPics(final String docContent) {
        final Matcher imgMatcher = Pattern.compile("<img.*?src=[^>]*?>").matcher(docContent);
        final List<String> fdIds = new ArrayList<String>();
        while (imgMatcher.find()) {
            final String img = imgMatcher.group();
            final Matcher srcMatcher = Pattern.compile("\".*?/resource/fckeditor/editor/filemanager/download.*?\"").matcher(img);
            while (srcMatcher.find()) {
                final String url = srcMatcher.group().substring(1, srcMatcher.group().length() - 1);
                final Matcher fdIdMatcher = Pattern.compile("fdId=([^&]*)").matcher(url);
                while (fdIdMatcher.find()) {
                    fdIds.add(fdIdMatcher.group(1));
                }
            }
        }
        return fdIds;
    }
    
    private List<String> getRtfVideos(final String docContent) {
        final Matcher videoMatcher = Pattern.compile("<video.*?src=[^>]*?>").matcher(docContent);
        final List<String> fdIds = new ArrayList<String>();
        while (videoMatcher.find()) {
            final String video = videoMatcher.group();
            final Matcher srcMatcher = Pattern.compile("\".*?/resource/fckeditor/editor/filemanager/download.*?\"").matcher(video);
            while (srcMatcher.find()) {
                final String url = srcMatcher.group().substring(1, srcMatcher.group().length() - 1);
                final Matcher fdIdMatcher = Pattern.compile("fdId=([^&]*)").matcher(url);
                while (fdIdMatcher.find()) {
                    fdIds.add(fdIdMatcher.group(1));
                }
            }
        }
        return fdIds;
    }
    
    public void convertFormToModel(final IExtendForm form, final IBaseModel model, final RequestContext requestContext) throws Exception {
        if (form instanceof ISysAttRtfForm && model instanceof ISysAttRtfModel) {
            final ISysAttRtfForm _form = (ISysAttRtfForm)form;
            final ISysAttRtfModel _model = (ISysAttRtfModel)model;
            final String docContent = _form.getDocContent();
            if (StringUtil.isNull(docContent)) {
                return;
            }
            int length = 100;
            final String clearHTML = StringUtil.clearHTMLTag(docContent);
            if (StringUtil.isNotNull(clearHTML)) {
                if (clearHTML.length() < 100) {
                    length = clearHTML.length();
                }
                _model.setFdRtfSummary(clearHTML.substring(0, length));
            }
        }
    }
    
    public void update(final IBaseModel model) throws Exception {
        this.save(model);
    }
    
    public void cloneModelToForm(final IExtendForm form, final IBaseModel model, final RequestContext requestContext) throws Exception {
        if (form instanceof ISysAttRtfForm && model instanceof ISysAttRtfModel) {
            final ISysAttRtfModel _model = (ISysAttRtfModel)model;
            final String docContent = _model.getDocContent();
            if (StringUtil.isNull(docContent)) {
                return;
            }
            final List<String> fdIds = this.getRtfPics(docContent);
            final HQLInfo hqlInfo = new HQLInfo();
            hqlInfo.setWhereBlock("sysAttRtfData.fdId in(:fdIds)");
            hqlInfo.setParameter("fdIds", (Object)fdIds);
            hqlInfo.setModelName(SysAttRtfData.class.getName());
            final List<SysAttRtfData> list = this.getSysAttMainService().findList(hqlInfo);
            for (final SysAttRtfData rtf : list) {
                final String fdId = rtf.getFdId();
                final SysAttRtfData _rtf = (SysAttRtfData)rtf.clone();
                _rtf.setFdModelId(form.getFdId());
                final String _fdId = this.getSysAttMainService().add((IBaseModel)_rtf);
                docContent.replace(fdId, _fdId);
            }
            final ISysAttRtfForm _form = (ISysAttRtfForm)form;
            _form.setDocContent(docContent);
        }
    }
}
